@@ -1,9 +1,9 @@
 #!/usr/bin/python3
 
 import time
-from large_index.log import logging
+from large_index.log import Log
 
-class Function:
+class Function(Log):
   def __init__(self,
     next_index: str = '',
     retry: int = 0,
@@ -23,12 +23,17 @@ class Function:
 
   def time_sleep(self):
     if self.retry > 0:
-      logging.warning("Sleep time {0}".format( int(60 * self.retry) ))
+      self.logger.warning("Sleep time {0}".format( int(60 * self.retry) ))
       time.sleep(60 * self.retry)
 
 if __name__ == "__main__":
   class_function = Function()
   class_function.debug_detail_index()
 
+  class_function.remove_old_log_file()
+  class_function.get_file_handler()
+  class_function.get_stream_handler()
+  class_function.get_logger()
+
   class_function.find_next_index()
   class_function.time_sleep()
